% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/funcGam.R
\name{functionalGam}
\alias{functionalGam}
\title{General additive model with functional response}
\usage{
functionalGam(data, x, designmat, weights, formula, family = "gaussian", ...)
}
\arguments{
\item{data}{a dataframe with the following columns: Y = functional response;
sample_id = sample ID; image_id = image ID;}

\item{x}{the x-axis values of the functional response}

\item{designmat}{a design matrix as defined by model.matrix()}

\item{weights}{weights as the number of points per image. These weights are
normalised by the mean of the weights in the fitting process}

\item{formula}{the formula for the model. The colnames of the designmatrix
have to correspond to the variables in the formula.}

\item{family}{the distributional family as implemented in \code{family.mgcv}. For
fast computation the default is set to \code{gaussian}. If the covariance scales
e.g. as a function of the domain, this estimation can be improved with
\code{gaulss} - for more information see \code{family.mgcv}.}

\item{...}{Other parameters passed to \code{pffr}}
}
\value{
a fitted pffr object which inherits from gam
}
\description{
A function that takes the output of a metric calculation as done by
\code{calcMetricPerFov}. The data has to be prepared into the correct format for
the functional analysis by the \code{prepData} function. The output is a \code{pffr}
object as implemented by \code{refund}.
}
\examples{
# load the pancreas dataset
library("tidyr")
library("dplyr")
spe <- imcdatasets::Damond_2019_Pancreas("spe", full_dataset = FALSE)
# calculate the Gcross metric for alpha and beta cells
metricRes <- calcMetricPerFov(spe, c("alpha", "beta"),
    subsetby = "image_number", fun = "Gcross",
    marks = "cell_type", rSeq = seq(0, 50, length.out = 50),
    c("patient_stage", "patient_id", "image_number"), ncores = 1
)
metricRes$ID <- paste0(
  metricRes$patient_stage, "|", metricRes$patient_id,
  "|", metricRes$image_number
)
# prepare data for FDA
dat <- prepData(metricRes, "r", "rs")

# drop rows with NA
dat <- dat |> drop_na()

# create meta info of the IDs
splitData <- strsplit(dat$ID, "|", fixed = TRUE)
dat$condition <- factor(sapply(splitData, function(x) x[1]))
dat$patient_id <- factor(sapply(splitData, function(x) x[2]))
dat$image_id <- factor(sapply(splitData, function(x) x[3]))
# create a designmatrix
condition <- dat$condition
# relevel the condition - can set explicit contrasts here
condition <- relevel(condition, "Non-diabetic")
designmat <- model.matrix(~condition)
# colnames don't work with the '-' sign
colnames(designmat) <- c(
    "Intercept", "conditionLong_duration",
    "conditionOnset"
)
# fit the model
mdl <- functionalGam(
    data = dat, x = metricRes$r |> unique(),
    designmat = designmat, weights = dat$npoints,
    formula = formula(Y ~ conditionLong_duration +
        conditionOnset + s(patient_id, bs = "re"))
)
summary(mdl)
}
